Class: Philiprehberger::TaskQueue::Entry

Inherits:
Struct
  • Object
show all
Defined in:
lib/philiprehberger/task_queue/queue.rb

Overview

Internal representation of an enqueued task, carrying its priority and the number of attempts made so far (for retry accounting).

Instance Attribute Summary collapse

Instance Attribute Details

#attemptsObject

Returns the value of attribute attempts

Returns:

  • (Object)

    the current value of attempts



9
10
11
# File 'lib/philiprehberger/task_queue/queue.rb', line 9

def attempts
  @attempts
end

#callableObject

Returns the value of attribute callable

Returns:

  • (Object)

    the current value of callable



9
10
11
# File 'lib/philiprehberger/task_queue/queue.rb', line 9

def callable
  @callable
end

#priorityObject

Returns the value of attribute priority

Returns:

  • (Object)

    the current value of priority



9
10
11
# File 'lib/philiprehberger/task_queue/queue.rb', line 9

def priority
  @priority
end